qualpal.Color
=============

.. currentmodule:: qualpal

.. autoclass:: Color
   :members:
   :show-inheritance:
   :inherited-members:
   :special-members: __call__, __add__, __mul__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Color.distance
      ~Color.from_hsl
      ~Color.from_rgb
      ~Color.hex
      ~Color.hsl
      ~Color.lab
      ~Color.lch
      ~Color.rgb
      ~Color.rgb255
      ~Color.simulate_cvd
      ~Color.xyz
   
   

   
   
   